package com.xiaomi.youpin.decrypt.demo.v2.controller;

import com.xiaomi.youpin.decrypt.demo.v2.model.OrderInfo;
import com.xiaomi.youpin.decrypt.demo.v2.model.Result;
import com.xiaomi.youpin.decrypt.demo.v2.service.OrderPushService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Map;

/**
 * version:2.1.1 -- 2020/7/17 14:58:51
 * 订单推送V2版数据解密demo
 * 文档：https://shop.xiaomiyoupin.com/openapi/doc/openapi_v2/11-orderpush.html
 */

@Slf4j
@RequestMapping("/api/order")
@RestController
public class OrderPushController {

    @Autowired
    private OrderPushService orderPushService;

    @PostMapping("/push/v2")
    public Result handleOrderpush(@RequestBody Map<String, String> params) {
        try {

            String partnerId = params.get("partnerId");
            String data = params.get("data");
            String sign = params.get("sign");
            String timestamp = params.get("timestamp");

            OrderInfo orderInfo = orderPushService.parseData(partnerId, data, sign, timestamp);
            log.info("解析成功:{}", orderInfo);

            /**
             *  解析数据后，商家可在此添加业务逻辑
             */
            return Result.success();

        } catch (Exception e) {
            log.error(e.toString());
            return Result.fromException(e);
        }
    }
}
