package com.xiaomi.youpin.decrypt.demo.v2.service.impl;

import com.xiaomi.youpin.decrypt.demo.v2.enums.ErrorCode;
import com.xiaomi.youpin.decrypt.demo.v2.errors.ExceptionHelper;
import com.xiaomi.youpin.decrypt.demo.v2.model.PartnerInfo;
import com.xiaomi.youpin.decrypt.demo.v2.model.TodoorTicket;
import com.xiaomi.youpin.decrypt.demo.v2.service.TodoorService;
import com.xiaomi.youpin.decrypt.demo.v2.utils.AesUtils;
import com.xiaomi.youpin.decrypt.demo.v2.utils.JacksonUtils;
import com.xiaomi.youpin.decrypt.demo.v2.utils.ParamUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

@Slf4j
@Service
public class TodoorServiceImpl implements TodoorService {

    // 初始化商家
    private PartnerInfo partner = new PartnerInfo();

    @Override
    public TodoorTicket parseData(String partnerId, String data, String sign, String timestamp) throws Exception {

        // 签名校验
        if (!ParamUtils.checkSign(partnerId, data, timestamp, partner.getKey(), sign)) {
            throw ExceptionHelper.create(ErrorCode.SIGN_ERROR);
        }

        // AES解密
        String result;
        try {
            result = AesUtils.decrypt(partner.getAesKey(), data);
            log.info("data:{}", result);
        } catch (Exception e) {
            throw ExceptionHelper.create(ErrorCode.AES_ERROR);
        }

        // 解析JSON
        try {
            TodoorTicket todoorTicket = JacksonUtils.fromJson(result, TodoorTicket.class);
            return todoorTicket;
        } catch (Exception e) {
            throw ExceptionHelper.create(ErrorCode.JSON_ERROR);
        }
    }
}
