package common;

import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.SerializationFeature;

public class JacksonUtils {

    private static ObjectMapper jacksonMapper;

    static {
        jacksonMapper = new ObjectMapper();
        // 反序列化遇见未知属性时不抛出异常, 默认抛出异常
        jacksonMapper.disable(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES);
        // 遇见不存在的bean时不提示错误
        jacksonMapper.disable(SerializationFeature.FAIL_ON_EMPTY_BEANS);
        // 反序列化遇见空字符串时按NULL对象处理
        jacksonMapper.enable(DeserializationFeature.ACCEPT_EMPTY_STRING_AS_NULL_OBJECT);
        // ... 其它需要配置的均可在此配置
        // 更多配置参考 https://github.com/FasterXML/jackson-databind/wiki/Deserialization-Features
    }


    /**
     * 普通对象序列化为字符串
     *
     * @param o 普通对象
     * @return 序列化后的字符串
     * @throws Exception 序列化异常
     */
    public static String toJson(Object o) throws Exception {
        return jacksonMapper.writeValueAsString(o);
    }
}
