package common;

import org.apache.commons.codec.digest.DigestUtils;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;

public class OpenApiUtils {

    private PartnerInfo partner;

    private final String urlTest = "http://openapi.test.youpin.mi.com";
    private final String urlOnline = "https://shopapi.io.mi.com";

    private final Map<String, String> apiDict2 = new HashMap<String, String>() {
        {
            put("singleDelivery", "/mtop/aftersale/openapi/delivery/single");
            put("modifyExpress", "/mtop/aftersale/openapi/delivery/update");
            put("orderList", "/mtop/aftersale/openapi/order/list");
            put("logisticsBatch", "/mtop/aftersale/openapi/logistics/batch");
        }
    };

    public void SetShop(PartnerInfo partner) {
        this.partner = partner;
    }

    public String api(String method, Map<String, Object> data, String env) {
        if (!env.equals("online")) {
            env = "test";
        }

        try {
            String res = fetch(method, data, env);
            return res;
        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }

    private String fetch(String method, Map<String, Object> data, String env) throws Exception {

        // 请求参数格式为json数组
        List<Map<String, Object>> request = new ArrayList<>();
        try {
            request.add(parseParam(data));
        } catch (Exception e) {
            throw new Exception(e.toString() + "参数解析错误");
        }

        String url = env.equals("online") ? urlOnline : urlTest;

        // for debug
        System.out.printf("\nurl: %s", url);
        System.out.printf("\nrequest: %s", JacksonUtils.toJson(request));

        String content = null;

        // Content-Type:application/json
        content = HttpUtils.postJson(url + apiDict2.get(method), null, null, JacksonUtils.toJson(request));
        return content;

    }

    private Map<String, Object> parseParam(Map<String, Object> param) throws Exception {
        // 加密文档参考:https://shop.xiaomiyoupin.com/openapi/doc/openapi_v2/1-public-params.html
        // 对data加密
        String dataValue = AesUtils.encrypt(partner.aesKey, JacksonUtils.toJson(param));

        String timeStamp = String.valueOf(System.currentTimeMillis() / 1000);

        Map<String, Object> signParam = new TreeMap<String, Object>();
        signParam.put("data", dataValue);
        signParam.put("partnerId", partner.partnerId);
        signParam.put("timestamp", timeStamp);

        // 用md5生成签名,同时拼接一个签名密钥
        String sign = getSign(signParam);
        signParam.put("sign", sign);

        return signParam;
    }

    // 生成签名
    public String getSign(Map<String, Object> signParam) {

        // 签名规则参考文档
        StringBuilder builder = new StringBuilder();
        builder.append("data=");
        builder.append(signParam.get("data"));
        builder.append("&partnerId=");
        builder.append(signParam.get("partnerId"));
        builder.append("&timestamp=");
        builder.append(signParam.get("timestamp"));
        builder.append(partner.key);

        // for debug
        System.out.println(builder.toString());

        return DigestUtils.md5Hex(builder.toString().getBytes());
    }
}