package com.xiaomiyoupin.orderpush.controller;

import com.xiaomiyoupin.orderpush.controller.struct.OrderPushResponse;
import com.xiaomiyoupin.orderpush.model.OrderInfo;
import com.xiaomiyoupin.orderpush.result.Result;
import com.xiaomiyoupin.orderpush.service.impl.OrderPushServiceImpl;
import com.xiaomiyoupin.orderpush.utils.JacksonUtils;
import com.xiaomiyoupin.orderpush.utils.ParamUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.Map;

/**
 * 项目测试 CURL：
 * curl --request POST \
 * --url http://127.0.0.1:8080/api/youpin/push \
 * --header 'content-type: application/x-www-form-urlencoded' \
 * --data 'data=b8Gc9gBsCaKHH5GLtVDyBwXQD6MC7aPmUdOmPbuijULJi2hQV1i7%2Fu7n0XBbhRBXv8nu0BFSt4X6g%2FTkgb8L9NS9HcIGE2rs5qGU05YufxINjqasRuZtsci7EqCbUn01BZ3BH34%2BiFf3aaiouZJaM28ZDwgo5Hu%2FWuVjKPn33E5gCyr9AogQGRu2EZjQNqCX5tRyhNVJjGhJVHVw8V1FvctvYls3wXjd%2B2ssxG8EcPBRySOFppsJrZfgLPvYbi8QAo81L69MKPTNGUxgdnaPZ7pHEHjsbjMzUbCWsware%2F9HirMmNDw4GXLu51hO2B3zFJJjceqHD%2FRraE6262UFP%2BenaJCv0Qg8is5Zf3GkqxZrArnYOTOXjp8hjIgalReJQgz925O8D2Wqf7JZJ9NwsKdXFLe1FVWK%2BbmbS1O7T7v9sjsOkwdi29J3905IVm6z8kaf4bLIzTsZjNkmaaPwHDqva887JUrxHatR6BkB9Vf3n9EcwdDOKta9qf7Im9vCQd57rCBEpafa%2FlMnS7U8QO5UjYlyuPWQXysduyhk8Y5fFl%2Fv%2Bx2lwyUramMcgmSwrkHBZyYEbz%2BJwtzIW0duBAFAIlwvBvRCa9JIfi0dSXxm5E5OOd9sOoI42%2BqiP6TUsw4VF%2BwSWId3Qj5A4xpi%2FQJKCJ88AZPlHTdJqcMXSBHa2MOTTWJPrVyZY9gGcYKjt5KppsBnBF3LFSJEOhZNuLBueD5i7YBFZKbpogg8FkzSQUcAtSUu%2BzjfpWb5fBWNUwqvO%2Bkel0H%2B1te%2BIgQjWC4p%2Fxj%2F1cy4%2BUw5gtq6U9sBZcT5EDrTJG%2BkSThZQmLtbB1zDz4%2BUVnPIdetthKUHtrKuKXomqJ014KPCjvMNQ3nE7gtGr2Od762%2FhT14VAGNfvkw1ZNdnQ8N9zxk0g1RJClqK2DNsUkzTRLSHsOasHzb5OFhTLwSBnlHvEq0Bo8a%2FSWeIPt8ltV6nuciWSHeyda210g6PqTIC1KWW3PBx7tyXPeMON%2BbaWOX2zJXrA23R4%2BhSOeEs8jzl%2FeQOlmCquFMkeqb8EM%2FMwqqcnJX1paMzV5sjUCYoFdQOdvRByY5DC5yV3wd%2BdCBJMiqM6B9gUMK82i4D4GIyD3S2obqaievF3zbtliTqC67t6iw%2B7dARBe%2BO%2F6f%2FBfrfVgC%2FRquQnPdtd67C7ZG8yzEGLEnJp0NB5ifNp3c%2FQSJfRAKzuJqYjWhxA7A%2B6EnyDQBZgt5WW43vLdbY7ZZVAQicu1eF6cqCLjmUcV2mE7qhrXjMIeVCTpOeNp3nw%2BV0jwgXrmidCwKprH5L2Zg8CUnNl3EP9s2oFycPhwIo%2FKkh6z7SCS82%2BThYUy8EgZ5R7xKtAaPLHvAa7eU%2BG2t65b7YaUJ1XAHI2nueo3FB%2F%2FmboEyr%2BEq9%2BA1l9hmQy25IM%2FKwyBFb2TGVTeyTgYFvsQL1jv4cMFMt8%2FW4gZ7v0NZDdyo6oboVi5GbwudtCQEw%2FcQ3vkSwR1A%2Bbdk55xO4oy%2FOnFmLkMMTf%2FEd14YnhFUdHf%2Fp5hYexiGyfzbeSFkEhzR9XWQaCL61BEkkKd2pjvX08L2BzhyIjO%2FobE7JZfPlNOECUj%2FzPU6o2HyYuO2vcB2XX%2F8er2ODY6E1KGvzu0DBg9hsgskXZbXERqr%2FrRkuPIh2Vdwmv4fXcjfErUL0e6yxb%2BKRCZ2xPK5CY2dxGkILrLGtr4LmlziiMo8dEaqFL3a4%2FC9LN%2BF4Teuw%2FTvzVNGq1ICs2oHtgXB431G3Yt3x3Taq78DMp4j%2B0d%2FL6xkReRWe0LZvmeEvbBxxTTAm51SwfsFHBNjEMk2PBX16MR1%2FYMI09p27c4hvR4Tok%2FJOpA2LvC6Yi6g9bV6ryi9CeXc%2B6J50XU3HSp3RUNWYIHk61DsNAz5Va2DLwx0MokrC6Wb7KuDheu%2FIc4hA8xT1e9DfZq%2BgGvkTjiCWXq4dfwJYfrvxSAPgq9zruf5xAnBCcM%2Bnv9AwKDsEkqUP140xlKJDUwCPcHlSvKA1%2BIZEbOzak8agvQ5OHCZlNBxXaqmVxPqCCh47%2BnDfJxREICqVMKZQbbqnAtv9d98yH7LO%2BNYcHWMwlsVEWw57XlawYo7bt7jFbsnagKwtjrJmp4wYkHvx1fEA%3D%3D&partner_id=88&sign=8dc4af1c0489875db644e34a8845da46&timestamp=1577699899'
 *
 * 单元测试:
 * com.xiaomiyoupin.orderpush.OrderPushTests
 */

@Slf4j
@Controller
public class OrderPushController {

    @Autowired
    private OrderPushServiceImpl orderPushService;

    @PostMapping(value = "api/youpin/push")
    @ResponseBody
    public Result<OrderPushResponse> handleOrderPush(@RequestBody String request) throws Exception {

        // for test
        log.info("request: {}", request);

        Map<String, String> requestMap = ParamUtils.ToParamsMap(request);
        String partnerId = requestMap.get("partner_id");
        String data = requestMap.get("data");
        String timestamp = requestMap.get("timestamp");
        String sign = requestMap.get("sign");
        String result = orderPushService.parseData(partnerId, data, timestamp, sign);

        OrderInfo orderInfo = JacksonUtils.fromJson(result, OrderInfo.class);
        OrderPushResponse response = new OrderPushResponse();
        response.setOrderInfo(orderInfo);
        log.info("OrderInfo:{}", orderInfo);
        return Result.success(response);
    }
}
