package com.xiaomiyoupin.orderpush.model;


import com.fasterxml.jackson.annotation.JsonProperty;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

import java.io.Serializable;
import java.util.List;

@Getter
@Setter
@ToString
public class OrderInfo implements Serializable {

    /**
     * 收货人地址
     */
    private String address;

    /**
     * 是否已经全部发货：1-是,0-否
     */
    @JsonProperty("alldelivery")
    private Integer allDelivery;

    /**
     * 发货主体商户ID：65-有品配送,其他-自发货商家id
     */
    private Integer consignor;

    /**
     * 订单优惠金额（分）
     */
    @JsonProperty("coupon_amount")
    private Integer couponAmount;

    /**
     *订单创建时间戳
     */
    private Integer ctime;

    /**
     * 配送时间：1-不限送货时间,2-工作日送货,3-双休日/假日送货
     */
    @JsonProperty("delivery_time")
    private Integer deliveryTime;

    /**
     * 订单用户备注
     */
    private String description;

    /**
     * 订单额外信息
     */
    @JsonProperty("ext_info")
    private String extInfo;

    /**
     * 订单支付时间
     */
    private Integer ftime;

    /**
     * 商品名称（已废弃，填写为""）
     */
    @JsonProperty("goods_name")
    private String goodsName;

    /**
     * 商品最低价格（已废弃，填写为0）
     */
    @JsonProperty("goods_price")
    private Integer goodsPrice;

    /**
     * 发票类型：0-无发票,1-个人纸质普票,2-企业纸质普票,4-电子发票(旧版),5-个人电子普票,6-企业电子普票
     */
    private Integer invoice;

    /**
     * 发票开具税号
     */
    @JsonProperty("invoice_company_code")
    private String invoiceCompanyCode;

    /**
     * 发票开具通知邮箱
     */
    @JsonProperty("invoice_email")
    private String invoiceEmail;

    /**
     * 发票开具通知号码
     */
    @JsonProperty("invoice_phone")
    private String invoicePhone;

    /**
     * 发票抬头
     */
    @JsonProperty("invoice_title")
    private String invoiceTitle;

    /**
     * 订单ID
     */
    @JsonProperty("order_id")
    private Long orderId;

    /**
     * 订单类型
     */
    private Integer otype;

    /**
     * 商户ID
     */
    @JsonProperty("partner_id")
    private Integer partnerId;

    /**
     * 订单商品明细
     */
    private List<Product> products;

    private List<AftersaleOrders> aftersaleOrders;

    /**
     * 订单费用
     */
    @JsonProperty("ship_fee")
    private Integer shipFee;

    /**
     * 订单运费
     */
    @JsonProperty("shopbrand")
    private String shopBrand;

    /**
     * 订单总价
     */
    @JsonProperty("total_price")
    private Integer totalPrice;


    @Getter
    @Setter
    @ToString
    public static class Product implements Serializable {

        private Integer count;

        private Integer ctime;

        @JsonProperty("delivery_time")
        private Integer deliveryTime;

        @JsonProperty("deliverycount")
        private Integer deliveryCount;

        @JsonProperty("express_av_fee")
        private Integer expressAvFee;

        private Integer ftime;

        private Integer gid;

        @JsonProperty("invoice_status")
        private Integer invoiceStatus;

        private String name;

        @JsonProperty("order_id")
        private Long orderId;

        @JsonProperty("order_type")
        private Integer orderType;

        @JsonProperty("parent_id")
        private Integer parentId;

        private Integer pid;

        private Integer price;

        @JsonProperty("product_bizcode")
        private String productBizcode;

        @JsonProperty("product_express_sn")
        private String productExpressSn;

        @JsonProperty("product_price")
        private Integer productPrice;

        @JsonProperty("sale_price")
        private Integer salePrice;

        @JsonProperty("refund_id")
        private String refundId;

        @JsonProperty("refunddescription")
        private String refundDescription;

        @JsonProperty("refundprice")
        private Integer refundPrice;

        @JsonProperty("refundreason")
        private String refundReason;

        @JsonProperty("refundstatus")
        private Integer refundStatus;

        @JsonProperty("refundtype")
        private Integer refundType;

        private Integer rtime;

        private Integer status;

        private Long uid;

        @JsonProperty("express_sn")
        private String expressSn;

        @JsonProperty("bizcode")
        private String bizCode;
    }

    @Getter
    @Setter
    @ToString
    public static class AftersaleOrders implements Serializable {

        private String id;

        @JsonProperty("refund_type")
        private Integer refundType;

        @JsonProperty("order_id")
        private String orderId;

        private Integer pid;

        private Integer count;

        private String state;

        @JsonProperty("op_code")
        private String opCode;

        @JsonProperty("target_state")
        private String targetState;

        @JsonProperty("op_time")
        private Long opTime;

        @JsonProperty("self_supporting")
        private Integer selfSupporting;

        private String type;

        @JsonProperty("service_way")
        private String serviceWay;

        @JsonProperty("org_id")
        private String orgId;

        @JsonProperty("org_name")
        private String orgName;

        @JsonProperty("apply_reason")
        private String applyReason;

        private Integer arbitrable;

        private Integer evaluable;

        @JsonProperty("create_time")
        private Integer createTime;

        @JsonProperty("create_person")
        private Long createPerson;

        @JsonProperty("update_time")
        private Integer updateTime;

        @JsonProperty("update_person")
        private Long updatePerson;

        @JsonProperty("create_from")
        private String createFrom;

        @JsonProperty("user_express_sn")
        private String userExpressSn;

        @JsonProperty("user_express_name")
        private String userExpressName;

        private List<Refund> refundList;

        @Getter
        @Setter
        @ToString
        public static class Refund implements Serializable {

            @JsonProperty("refund_fee")
            private Integer refundFee;

            @JsonProperty("refund_status")
            private String refundStatus;

            @JsonProperty("notify_time")
            private Integer notifyTime;

            private String state;

            private Integer pid;

            private Integer count;

            @JsonProperty("pay_type")
            private Integer payType;
        }
    }
}
