package com.xiaomiyoupin.orderpush.result;

import com.xiaomiyoupin.orderpush.errors.BizError;
import com.xiaomiyoupin.orderpush.errors.ErrorCode;
import com.xiaomiyoupin.orderpush.errors.GeneralCodes;
import lombok.Getter;

import java.io.Serializable;

public class Result<T> implements Serializable {

    @Getter
    private int code;

    @Getter
    private String message;

    @Getter
    private T data;

    private static String SUCCESS_MESSAGE = "ok";

    /**
     * 不允许自己创建Result，只可以使用静态方法创建
     */
    Result(int code, String message, T data) {
        this.code = code;
        this.message = message;
        this.data = data;
    }

    public static <T> Result<T> success(T data) {
        return new Result<>(0, SUCCESS_MESSAGE, data);
    }

    public static <T> Result<T> fail(ErrorCode code, String message) {
        return new Result<>(code.getCode(), message, null);
    }

    public static <T> Result<T> fromException(Throwable e) {
        if (e instanceof BizError) {
            return new Result<>(((BizError) e).getCode(), ((BizError) e).getMessage(), null);
        } else {
            return fail(GeneralCodes.InternalError, "系统繁忙，请稍后再试");
        }
    }

    public static <T> Result<T> fromException(Throwable e, String message) {
        if (e instanceof BizError) {
            return new Result<>(((BizError) e).getCode(), message, null);
        } else {
            return fail(GeneralCodes.InternalError, message);
        }
    }

    @Override
    public String toString() {
        return String.format("Result{code=%d, message=%s, data=%s}", code, message, data);
    }

}
