package com.xiaomiyoupin.orderpush.service.impl;

import com.xiaomiyoupin.orderpush.errors.BizError;
import com.xiaomiyoupin.orderpush.errors.ExceptionHelper;
import com.xiaomiyoupin.orderpush.errors.OrderPushError;
import com.xiaomiyoupin.orderpush.model.PartnerInfo;
import com.xiaomiyoupin.orderpush.service.OrderPushService;
import com.xiaomiyoupin.orderpush.utils.AesUtils;
import com.xiaomiyoupin.orderpush.utils.ParamUtils;
import org.springframework.stereotype.Service;

import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;


@Service
public class OrderPushServiceImpl implements OrderPushService {

    // 初始化商家
    private PartnerInfo partner = new PartnerInfo();

    @Override
    public String parseData(String partnerId, String data, String timestamp, String sign) throws BizError {

        //先解码，再校验签名
        try {
            data = URLDecoder.decode(data, "UTF8");
        } catch (UnsupportedEncodingException ex) {
            throw ExceptionHelper.create(OrderPushError.CODE_PARAMS_ERROR, "data 解码失败");
        }

        // 签名校验
        if (!ParamUtils.checkSign(partnerId, data, timestamp, partner.getKey(), sign)) {
            throw ExceptionHelper.create(OrderPushError.CODE_SIGN_NOT_MATCH_ERROR, "签名校验失败");
        }


        try {
            String res = AesUtils.decrypt(partner.getAesKey(), data);
            return res.trim();
        } catch (Exception e) {
            throw ExceptionHelper.create(OrderPushError.CODE_PARAMS_ERROR, e.getMessage());
        }
    }
}
