package com.xiaomiyoupin.orderpush.utils;

import com.xiaomiyoupin.orderpush.errors.BizError;
import com.xiaomiyoupin.orderpush.errors.ExceptionHelper;
import com.xiaomiyoupin.orderpush.errors.OrderPushError;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.digest.DigestUtils;

import java.util.HashMap;
import java.util.Map;

@Slf4j
public class ParamUtils {

    // 切分参数
    public static Map<String, String> ToParamsMap(String params) throws BizError {

        Map<String, String> map = new HashMap<>(8);
        String[] keyValuePeers = params.split("&");

        if (keyValuePeers.length != 4) {
            throw ExceptionHelper.create(OrderPushError.CODE_PARAMS_ERROR, "参数解析异常");
        }

        for (String keyValueItem : keyValuePeers) {
            //加密参数中可能存在'='
            int pos = 0;
            int length = keyValueItem.length();
            for (int i = 0; i < length; i++) {
                if (keyValueItem.charAt(i) == '=') {
                    pos = i;
                    break;
                }
            }
            String[] kvi = new String[2];
            kvi[0] = keyValueItem.substring(0, pos);
            kvi[1] = keyValueItem.substring(pos + 1, length);
            if (kvi.length == 2) {
                map.put(kvi[0], kvi[1]);
            } else {
                throw ExceptionHelper.create(OrderPushError.CODE_PARAMS_ERROR, "参数解析异常");
            }
        }

        return map;
    }


    // 校验sign
    public static Boolean checkSign(String partnerId, String data, String timestamp, String key, String sign) {

        String targetString = String.format("data=%s&partner_id=%s&timestamp=%s%s", data, partnerId, timestamp, key);
        String calSign = DigestUtils.md5Hex(targetString);

        log.info("calSign: {} ", calSign);
        log.info("sign: {} ", sign);
        return calSign.equals(sign);
    }
}
