package com.xiaomiyoupin.orderpush;

import com.xiaomiyoupin.orderpush.service.impl.OrderPushServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;

@Slf4j
@SpringBootTest
class OrderPushTests {

    @Autowired
    private OrderPushServiceImpl orderPushService;

    @Test
    void OrderPushTest() throws Exception {
        // 单元测试
        String partnerId = "88";
        String data = "b8Gc9gBsCaKHH5GLtVDyBwXQD6MC7aPmUdOmPbuijULJi2hQV1i7%2fu7n0XBbhRBXv8nu0BFSt4X6g%2fTkgb8L9NS9HcIGE2rs5qGU05YufxINjqasRuZtsci7EqCbUn01BZ3BH34%2biFf3aaiouZJaM28ZDwgo5Hu%2fWuVjKPn33E5gCyr9AogQGRu2EZjQNqCX5tRyhNVJjGhJVHVw8V1FvctvYls3wXjd%2b2ssxG8EcPBRySOFppsJrZfgLPvYbi8QAo81L69MKPTNGUxgdnaPZ7pHEHjsbjMzUbCWsware%2f9HirMmNDw4GXLu51hO2B3zFJJjceqHD%2fRraE6262UFP%2benaJCv0Qg8is5Zf3GkqxZrArnYOTOXjp8hjIgalReJQgz925O8D2Wqf7JZJ9NwsKdXFLe1FVWK%2bbmbS1O7T7v9sjsOkwdi29J3905IVm6z8kaf4bLIzTsZjNkmaaPwHDqva887JUrxHatR6BkB9Vf3n9EcwdDOKta9qf7Im9vCQd57rCBEpafa%2flMnS7U8QO5UjYlyuPWQXysduyhk8Y5fFl%2fv%2bx2lwyUramMcgmSwrkHBZyYEbz%2bJwtzIW0duBAFAIlwvBvRCa9JIfi0dSXxm5E5OOd9sOoI42%2bqiP6TUsw4VF%2bwSWId3Qj5A4xpi%2fQJKCJ88AZPlHTdJqcMXSBHa2MOTTWJPrVyZY9gGcYKjt5KppsBnBF3LFSJEOhZNuLBueD5i7YBFZKbpogg8FkzSQUcAtSUu%2bzjfpWb5fBWNUwqvO%2bkel0H%2b1te%2bIgQjWC4p%2fxj%2f1cy4%2bUw5gtq6U9sBZcT5EDrTJG%2bkSThZQmLtbB1zDz4%2bUVnPIdetthKUHtrKuKXomqJ014KPCjvMNQ3nE7gtGr2Od762%2fhT14VAGNfvkw1ZNdnQ8N9zxk0g1RJClqK2DNsUkzTRLSHsOasHzb5OFhTLwSBnlHvEq0Bo8a%2fSWeIPt8ltV6nuciWSHeyda210g6PqTIC1KWW3PBx7tyXPeMON%2bbaWOX2zJXrA23R4%2bhSOeEs8jzl%2feQOlmCquFMkeqb8EM%2fMwqqcnJX1paMzV5sjUCYoFdQOdvRByY5DC5yV3wd%2bdCBJMiqM6B9gUMK82i4D4GIyD3S2obqaievF3zbtliTqC67t6iw%2b7dARBe%2bO%2f6f%2fBfrfVgC%2fRquQnPdtd67C7ZG8yzEGLEnJp0NB5ifNp3c%2fQSJfRAKzuJqYjWhxA7A%2b6EnyDQBZgt5WW43vLdbY7ZZVAQicu1eF6cqCLjmUcV2mE7qhrXjMIeVCTpOeNp3nw%2bV0jwgXrmidCwKprH5L2Zg8CUnNl3EP9s2oFycPhwIo%2fKkh6z7SCS82%2bThYUy8EgZ5R7xKtAaPLHvAa7eU%2bG2t65b7YaUJ1XAHI2nueo3FB%2f%2fmboEyr%2bEq9%2bA1l9hmQy25IM%2fKwyBFb2TGVTeyTgYFvsQL1jv4cMFMt8%2fW4gZ7v0NZDdyo6oboVi5GbwudtCQEw%2fcQ3vkSwR1A%2bbdk55xO4oy%2fOnFmLkMMTf%2fEd14YnhFUdHf%2fp5hYexiGyfzbeSFkEhzR9XWQaCL61BEkkKd2pjvX08L2BzhyIjO%2fobE7JZfPlNOECUj%2fzPU6o2HyYuO2vcB2XX%2f8er2ODY6E1KGvzu0DBg9hsgskXZbXERqr%2frRkuPIh2Vdwmv4fXcjfErUL0e6yxb%2bKRCZ2xPK5CY2dxGkILrLGtr4LmlziiMo8dEaqFL3a4%2fC9LN%2bF4Teuw%2fTvzVNGq1ICs2oHtgXB431G3Yt3x3Taq78DMp4j%2b0d%2fL6xkReRWe0LZvmeEvbBxxTTAm51SwfsFHBNjEMk2PBX16MR1%2fYMI09p27c4hvR4Tok%2fJOpA2LvC6Yi6g9bV6ryi9CeXc%2b6J50XU3HSp3RUNWYIHk61DsNAz5Va2DLwx0MokrC6Wb7KuDheu%2fIc4hA8xT1e9DfZq%2bgGvkTjiCWXq4dfwJYfrvxSAPgq9zruf5xAnBCcM%2bnv9AwKDsEkqUP140xlKJDUwCPcHlSvKA1%2bIZEbOzak8agvQ5OHCZlNBxXaqmVxPqCCh47%2bnDfJxREICqVMKZQbbqnAtv9d98yH7LO%2bNYcHWMwlsVEWw57XlawYo7bt7jFbsnagKwtjrJmp4wYkHvx1fEA%3d%3d";
        String timestamp = "1577699899";
        String sign = "8dc4af1c0489875db644e34a8845da46";

        String result = orderPushService.parseData(partnerId, data, timestamp, sign);
        log.info("result: {}", result);
    }

}
